import java.util.Random;

/**
 * Reprsentiert die Simulation einer Bankkarte.
 * Alle Bankkarten (die sich nicht gerade in einem
 * Terminal befinden) werden von dem Kartenleser
 * verwaltet. Dieser Simuliert die Karten, die
 * sich im Umlauf befinden.
 *
 * @see Karteninfo, Kartenleser
 */
public class Karte {

	/**
	 * Eindeutige Kartennummer.
	 */
    private int Kartennummer;

	/**
	 * Zugehriges Konto.
	 */
    private int Kontonummer;

	/**
	 * Zeitabhaengiger Wert fuer die
	 * verfuegbare Summe. 
	 */
    private ZeitWert VerfuegbareSumme;

	/**
	 * Private Identifikations Nummer, um die
	 * Sicherheit bei Verlust der Karte zu erhhen.
	 */
    private int pin;

	/**
	 * Speichert den zuletzt gesehenen Kontostand, um
	 * an einem Offline Terminal den Kontostand einsehen
	 * zu knnen.
	 */
	private ZeitWert LetzterKontostand;

	/**
	 * Es sind nur 3 Falscheingaben in einem bestimmten
	 * Zeitintervall erlaubt (momentan 1 Tag)
	 * Hier wird die Anzahl der Falscheingaben zeitabhaengig
	 * abgespeichert.	 
	 */
//	private ZeitWert Falscheingaben;
	private int falscheingaben;

	/*
	 * Wird zur Kontrolle aus den vorhergegangenen Werte
	 * berechnet.
	 */
	private int Checksum;
	


	/**
	 * Getter-Methode
	 *
	 * @return Kartennummer
	 */
	public int gibKartennummer()
	{
		return Kartennummer;
	}	

	/**
	 * Getter-Methode
	 *
	 * @return Kontonummer
	 */
	public int gibKontonummer()
	{
		return Kontonummer;
	}	

	/**
	 * Getter-Methode
	 *
	 * @return PIN
	 */
	public int gibPIN()
	{
		return pin;
	}

	/**
	 * Getter-Methode
	 *
	 * @return Checksum
	 */
	public int gibChecksum()
	{
		return Checksum;
	}

	/**
	 * Getter-Methode
	 *
	 * @return Verfuegbare Summe
	 */
	public ZeitWert gibVerfuegbareSumme()
	{
		return VerfuegbareSumme;
	}

	/**
	 * Getter-Methode
	 *
	 * @return Letzter Kontostand
	 */
	public ZeitWert gibLetzterKontostand()
	{
		return LetzterKontostand;
	}

	/**
	 * Getter-Methode
	 *
	 * @return  Anzahl der Falscheingaben
	 */
	public int gibFalscheingaben()
	{
		return falscheingaben;
	}

	/**
	 * Setter-Methode
	 *
	 * @param   zw neues ZeitWert Objekt
	 */
	public void setzeFalscheingaben(int i)
	{
		falscheingaben = i;
	}

	/**
	 * Erhoeht die Anzahl der Falscheingaben
	 * um 1.
	 *
	 */
	public void erhoeheFalscheingaben()
	{
		falscheingaben = falscheingaben +1;
	}

	/**
	 * Setter-Methode
	 *
	 * @params Verfuegbare Summe
	 */
	public void setzeVerfuegbareSumme(ZeitWert verfuegbar)
	{
		VerfuegbareSumme = verfuegbar;
	}

	/**
	 * Setter-Methode
	 *
	 * @params Letzter Kontostand
	 */
	public void setzeLetzterKontostand(ZeitWert kontostand)
	{
		LetzterKontostand = kontostand;
	}

	/**
	 * Setter-Methode
	 *
	 * @params PIN
	 */
	public void setzePIN(int pin)
	{
		pin = pin;
	}

	/**
	 * Setter-Methode
	 *
	 * @params Checksum
	 */
	public void setzeChecksum(int sum)
	{
		Checksum = sum;
	}
	
	/**
	 * Setter-Methode
	 *
	 * @params Kartennummer
	 */
	public void setzeKartennummer(int nummer)
	{
		Kartennummer = nummer;
	}
	
	/**
	 * Setter-Methode
	 *
	 * @params Kontonummer
	 */
	public void setzeKontonummer(int nummer)
	{
		Kontonummer = nummer;
	}

}
 
